/**
 * Provides the functionality to toggle sections with additional informations.
 *
 * The `.presentationUiTogglesection()` provides the functionality to toggle areas with additional informations.
 *
 * ### Examples
 * Explanation for example,
 *
 * JavaScript:
 *
 *
 *     <div class="ep-js" data-js=".presentationUiTogglesection({
 *         selector: $(elem).closest('.row').find('.ep-toggle-section-area'),
 *         duration: 800,
 *         iconElement: $(elem).find('.iconElement'),
 *         iconClass: {open: 'icon-plus', close: 'icon-minus'}
 *     })">
 *
 *
 * @class jQuery.ui.presentationUiDnduploader
 * @extends jQuery.widget
 *
 * @uses jquery
 * @uses jquery.ui.widget
 * @uses ep
 * @uses de_epages
 * @since 6.17.38
 */

/**
 * @cfg {Object} [options] A map of additional options pass to the method.
 */

/**
 * @cfg {String} [selector] A valid css selector, a DOM node or a jQuery element representing the toggle area.
 */

/**
 * @cfg {Integer} [duration] A number containing the duration of the animation.
 */

/**
 * @cfg {String} [iconElement] A valid css selector, a DOM node or a jQuery element representing the element which contains the state icon.
 */

/**
 * @cfg {Object} [iconClass] A object containing the icon classes for the icon states.
 */

/**
 * @cfg {Boolean} [expertmode] A valid css selector, a DOM node or a jQuery element representing the expert mode hidden input.
 */

/**
 * See `jQuery.ui.presentationUiTogglesection` for details.
 *
 * @param {Object} [options] A map of additional options pass to the method.
 * @param {String} [selector] A valid css selector, a DOM node or a jQuery element representing the toggle area.
 * @param {Integer} [duration] A number containing the duration of the animation.
 * @param {String} [iconElement] A valid css selector, a DOM node or a jQuery element representing the element which contains the state icon.
 * @param {Object} [iconClass] A object containing the icon classes for the icon states.
 * @param {Boolean} [expertmode] A valid css selector, a DOM node or a jQuery element representing the expert mode hidden input.
 *
 * @method trustbudgetUiToggle
 * @member jQuery
 *
 * @since 7.5.0
 */

/*
 * @copyright       © Copyright 2006-2010, epages GmbH, All Rights Reserved.
 *
 * @module          de_epages.trustedshops.ui.trustbadgetoggle
 *
 * @revision        $Revision$
 */

define( "de_epages/trustedshops/ui/trustbadgetoggle", [
    "jquery",
    "ep",
    "de_epages",

    "jquery/ui/widget"
], function ($, ep, de_epages) {

    $.widget('ui.trustbudgetUiToggle', {

        options: {
            selector: '.ep-toggle-section-area',
            duration: 600,
            iconElement: undefined,
            iconClass: {
                open: 'fa-minus',
                close: 'fa-plus'
            },
            expertmode: '#section-area'
        },

        _create: function () {
            var self = this,
                elem = self.element,
                o = self.options;

            // toggle area
            self.toggleArea = $(o.selector);
            elem.data('open', true);
            elem.data('expertmode', (o.expertmode.val() == 1) );

            // default icon element
            self.iconElement = o.iconElement===undefined ? elem.find('.fa') : $(o.iconElement);

            // register handling for toggle button
            elem.on('click', $.proxy(function (e) {
                self._toggleArea(e);
            }, self));

            // initial call to set toggle areas
            self._toggleArea();
        },

        _toggleArea: function (e) {
            var self = this,
                elem = self.element,
                o = self.options,
                isInitiallyOpen = elem.data('open'),
                expertmode = elem.data('expertmode');

            // stop already running animations and set state to the end
            self.toggleArea.stop(false, true);
            // toggle area

            self.toggleArea[isInitiallyOpen && !expertmode ? 'slideUp' : 'slideDown']({
                duration: o.duration,
                complete: function () {
                    var isFinallyOpen = self.toggleArea.css('display') != 'none';
                    self.iconElement.addClass(isFinallyOpen ? o.iconClass.open : o.iconClass.close);
                    self.iconElement.removeClass(isFinallyOpen ? o.iconClass.close : o.iconClass.open);

                    // set new state for area
                    elem.data('open', isFinallyOpen);
                    elem.data('expertmode', (o.expertmode.val() == 1) );
                }
            });


        },

        /**
         * This method removes the container on which the selection toggler has been appended to.
         *
         * @method destroy
         * @member jQuery.ui.presentationUiTogglesection
         *
         * @since 6.17.37
         */
        destroy: function () {
            var self = this;

            //self.elem.off('.presentationUiTogglesection');

            self._superApply(arguments);
        }

    });

    return de_epages;

});
